@@ -24,9 +24,7 @@ class NoseXML(Plugin, object):
 
 		nosetests --with-nosexml --xml-report-file=my_report.xml
 
-		Please note, with every run, the XML file will have the new test results appened inside. This is done to
-		allow multiple sequential executions of nosetest to build up a single report. You probably want to delete 
-		my_report.xml (or equivalent) prior to each full run.
+		Optional: --xml-accumulate will open and insert additional test results into an already existing xml file. The intention is to allow multiple independent runs of nosetest to create a single report.
 
 	Example output:
 
@@ -67,23 +65,32 @@ class NoseXML(Plugin, object):
 	def add_options(self, parser, env=os.environ):
 		Plugin.add_options(self, parser, env)
 		parser.add_option("--xml-report-file", action="store", default="nose_report.xml", dest="report_file", help="File to output XML report to")
+		parser.add_option("--xml-accumulate", action="store_true", dest="accumulate", help="Accumulate reults into report file, or start new")
 	
 	def configure(self, options, config):
 		Plugin.configure(self, options, config)
 		self.conf = config
 		self.reportFile = options.report_file
+		self.accumulate = options.accumulate
+
+	def _new_tree(self):
+		""" Initialise a new tree """
+		self.root = ET.Element("testset")
+		self.tree = ET.ElementTree(self.root)
+		metaElement = ET.SubElement(self.root, "meta")
+		ET.SubElement(metaElement, "datetime").text = str(datetime.datetime.now())
 
 	def begin(self):
-		""" If a file already exists, we add into that, otherwise, create a new one """
-		try:
-			self.tree = ET.parse(self.reportFile)
-			self.root = tree.getroot()
-		except:
-			self.root = ET.Element("testset")
-			self.tree = ET.ElementTree(self.root)
-			metaElement = ET.SubElement(self.root, "meta")
-			ET.SubElement(metaElement, "datetime").text = str(datetime.datetime.now())
-
+		""" If a file already exists and --xml-accumulate is set, we add into that, otherwise, create a new one """
+		if self.accumulate:
+			try:
+				self.tree = ET.parse(self.reportFile)
+				self.root = self.tree.getroot()
+			except IOError:
+				self._new_tree()
+		else:
+			self._new_tree()
+		
 	def finalize(self, result):
 		""" Write out report as serialized XML """
 		self.tree.write(self.reportFile)
